{{ ansible_managed | comment }}
[Unit]
Description=pcp-to-spark metrics export service
Documentation=man:pcp2spark(1)
After=network-online.target pmcd.service

[Service]
TimeoutSec=10
ExecStartPre=/usr/bin/pmrepconf -c \
             --option interval={{ spark_export_interval }} \
             --option spark_server={{ spark_export_server }} \
             --option spark_port={{ spark_export_port }} \
             {{ __spark_export_conf }}
ExecStart=/usr/bin/pcp2spark --include-labels :metrics
Restart=on-failure

[Install]
WantedBy=multi-user.target
