{{ ansible_managed | comment }}
apiVersion: 1

datasources:
- name: PCP Vector
  type: pcp-vector-datasource
  access: proxy
  orgId: 1
  url: http://{{ __grafana_pmproxy_server }}
  editable: true
  isDefault: true
- name: PCP Redis
  type: pcp-redis-datasource
  access: proxy
  orgId: 1
  url: http://{{ __grafana_pmproxy_server }}
  editable: true
- name: PCP bpftrace
  type: pcp-bpftrace-datasource
  access: proxy
  orgId: 1
  url: http://{{ __grafana_pmproxy_server }}
  editable: true
