{{ ansible_managed | comment }}
## Type:        string
## Default:	""
#
# Run the pmlogger_daily binary, via pmlogger_daily.service, with the
# following parameters.
#
PMLOGGER_DAILY_PARAMS="--discard {{ pcp_pmlogger_discard }}"

## Type:        string
## Default:	"-C"
#
# Run the pmlogger_check binary, via pmlogger_check.service, with the
# following parameters.
#
#PMLOGGER_CHECK_PARAMS=""

## Type:        string
## Default:	"-p"
#
# Run the pmlogger_daily binary, via pmlogger_daily_poll.service, with the
# following parameters.
#
#PMLOGGER_DAILY_POLL_PARAMS=""


## Type:        string
## Default:	"-o /var/log/pcp/sa/"
#
# Run the pmlogger_daily_report binary, via pmlogger_daily_report.service, with
# the following parameters.
#
#PMLOGGER_DAILY_REPORT_PARAMS=""

## Type:        string
## Default:	"-o /var/log/pcp/sa/ -p"
#
# Run the pmlogger_daily_report binary, via pmlogger_daily_report_poll.service,
# with the following parameters.
#
#PMLOGGER_DAILY_REPORT_POLL_PARAMS=""
